@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
   Copyright (c) 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
   This program is free software; you can redistribute it and/or modify it
@@ -40,7 +40,7 @@ class MAILCOMMON_EXPORT CollectionExpiryPage : public Akonadi::CollectionPropert
 
 public:
     explicit CollectionExpiryPage(QWidget *parent = nullptr);
-    ~CollectionExpiryPage();
+    ~CollectionExpiryPage() override;
 
     bool canHandle(const Akonadi::Collection &col) const override;
     void load(const Akonadi::Collection &collection) override;
@@ -59,17 +59,17 @@ private:
     void saveAndExpire(Akonadi::Collection &collection, bool saveSettings, bool _expirenow);
 
 private:
-    QCheckBox *expireReadMailCB;
-    KPluralHandlingSpinBox *expireReadMailSB;
-    QCheckBox *expireUnreadMailCB;
-    KPluralHandlingSpinBox *expireUnreadMailSB;
-    QRadioButton *moveToRB;
-    FolderRequester *folderSelector;
-    QRadioButton *deletePermanentlyRB;
-    QPushButton *expireNowPB;
+    QCheckBox *expireReadMailCB = nullptr;
+    KPluralHandlingSpinBox *expireReadMailSB = nullptr;
+    QCheckBox *expireUnreadMailCB = nullptr;
+    KPluralHandlingSpinBox *expireUnreadMailSB = nullptr;
+    QRadioButton *moveToRB = nullptr;
+    FolderRequester *folderSelector = nullptr;
+    QRadioButton *deletePermanentlyRB = nullptr;
+    QPushButton *expireNowPB = nullptr;
 
     Akonadi::Collection mCollection;
-    bool mChanged;
+    bool mChanged = false;
 };
 
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionExpiryPageFactory, CollectionExpiryPage)
