@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,15 +27,16 @@
 using namespace MailCommon;
 
 FilterImporterProcmail::FilterImporterProcmail(QFile *file)
-    : FilterImporterAbstract(), mFilterCount(0)
+    : FilterImporterAbstract()
+    , mFilterCount(0)
 {
     QTextStream stream(file);
     readStream(stream);
 }
 
 FilterImporterProcmail::FilterImporterProcmail(QString string)
-    : FilterImporterAbstract(),
-      mFilterCount(0)
+    : FilterImporterAbstract()
+    , mFilterCount(0)
 {
     QTextStream stream(&string);
     readStream(stream);
@@ -67,9 +68,7 @@ QString FilterImporterProcmail::createUniqFilterName()
     return i18n("Procmail filter %1", ++mFilterCount);
 }
 
-MailCommon::MailFilter *FilterImporterProcmail::parseLine(QTextStream &stream,
-        QString line,
-        MailCommon::MailFilter *filter)
+MailCommon::MailFilter *FilterImporterProcmail::parseLine(QTextStream &stream, QString line, MailCommon::MailFilter *filter)
 {
     Q_UNUSED(stream);
     if (line.isEmpty()) {
@@ -78,26 +77,25 @@ MailCommon::MailFilter *FilterImporterProcmail::parseLine(QTextStream &stream,
     } else if (line.startsWith(QLatin1Char('#'))) {
         //Commented line
         return filter;
-    } else if (line.startsWith(QStringLiteral(":0"))) {
+    } else if (line.startsWith(QLatin1String(":0"))) {
         appendFilter(filter);
         filter = new MailFilter();
         const QString uniqName = createUniqFilterName();
         filter->pattern()->setName(uniqName);
         filter->setToolbarName(uniqName);
-
-    } else if (line.startsWith(QStringLiteral("* "))) {
+    } else if (line.startsWith(QLatin1String("* "))) {
         line.remove(0, 2);
         QByteArray fieldName;
         SearchRule::Function functionName = SearchRule::FuncRegExp;
-        if (line.startsWith(QStringLiteral("^From:"))) {
+        if (line.startsWith(QLatin1String("^From:"))) {
             line.remove(QStringLiteral("^From:"));
             fieldName = "from";
-        } else if (line.startsWith(QStringLiteral("^Subject:"))) {
+        } else if (line.startsWith(QLatin1String("^Subject:"))) {
             line.remove(QStringLiteral("^Subject:"));
             fieldName = "subject";
-        } else if (line.startsWith(QStringLiteral("^Sender:"))) {
+        } else if (line.startsWith(QLatin1String("^Sender:"))) {
             line.remove(QStringLiteral("^Sender:"));
-        } else if (line.startsWith(QStringLiteral("^(To|Cc):"))) {
+        } else if (line.startsWith(QLatin1String("^(To|Cc):"))) {
             line.remove(QStringLiteral("^(To|Cc):"));
             fieldName = "<recipients>";
         } else {
