@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,9 +22,7 @@
 #include <EntityOrderProxyModel>
 #include "mailcommon_export.h"
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 /**
  * @brief The EntityCollectionOrderProxyModel class implements ordering of mail collections.
  * It supports two modes: manual sorting and automatic sorting.
@@ -44,9 +42,9 @@ class MAILCOMMON_EXPORT EntityCollectionOrderProxyModel : public Akonadi::Entity
 public:
     explicit EntityCollectionOrderProxyModel(QObject *parent = nullptr);
 
-    virtual ~EntityCollectionOrderProxyModel();
+    ~EntityCollectionOrderProxyModel() override;
 
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
     void setManualSortingActive(bool active);
     bool isManualSortingActive() const;
@@ -61,8 +59,6 @@ private:
     class EntityCollectionOrderProxyModelPrivate;
     EntityCollectionOrderProxyModelPrivate *const d;
 };
-
 }
 
 #endif
-
