@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -46,7 +46,7 @@ public:
 
     explicit FolderTreeView(KXMLGUIClient *xmlGuiClient, QWidget *parent = nullptr, bool showUnreadCount = true);
 
-    virtual ~FolderTreeView();
+    ~FolderTreeView() override;
 
     void selectNextUnreadFolder(bool confirm = false);
     void selectPrevUnreadFolder(bool confirm = false);
@@ -104,15 +104,25 @@ Q_SIGNALS:
     void newTabRequested(bool);
 
 private:
+    enum SearchDirection {
+        ForwardSearch,
+        BackwardSearch
+    };
+
+    QModelIndex indexAbove(const QModelIndex &current) const;
+    QModelIndex indexBelow(const QModelIndex &current) const;
+    QModelIndex lastChild(const QModelIndex &current) const;
+    QModelIndex nextUnreadCollection(const QModelIndex &current, SearchDirection direction) const;
+
     bool ignoreUnreadFolder(const Akonadi::Collection &, bool) const;
     bool allowedToEnterFolder(const Akonadi::Collection &, bool) const;
-    bool trySelectNextUnreadFolder(const QModelIndex &, MailCommon::Util::SearchDirection, bool);
+    bool trySelectNextUnreadFolder(const QModelIndex &, SearchDirection, bool);
 
     FolderTreeWidget::ToolTipDisplayPolicy mToolTipDisplayPolicy;
     FolderTreeWidget::SortingPolicy mSortingPolicy;
-    Akonadi::CollectionStatisticsDelegate *mCollectionStatisticsDelegate;
-    bool mbDisableContextMenuAndExtraColumn;
-    bool mbDisableSaveConfig;
+    Akonadi::CollectionStatisticsDelegate *mCollectionStatisticsDelegate = nullptr;
+    bool mbDisableContextMenuAndExtraColumn = false;
+    bool mbDisableSaveConfig = false;
 };
 }
 
