@@ -33,8 +33,6 @@
 #include <Collection>
 #include <Item>
 
-#include <QList>
-
 class KJob;
 
 namespace MailCommon {
@@ -43,7 +41,7 @@ class ExpireJob : public ScheduledJob
     Q_OBJECT
 public:
     explicit ExpireJob(const Akonadi::Collection &folder, bool immediate);
-    virtual ~ExpireJob();
+    ~ExpireJob() override;
 
     void execute() override;
     void kill() override;
@@ -57,8 +55,8 @@ private:
 
 private:
     Akonadi::Item::List mRemovedMsgs;
-    int mMaxUnreadTime;
-    int mMaxReadTime;
+    qint64 mMaxUnreadTime;
+    qint64 mMaxReadTime;
     Akonadi::Collection mMoveToFolder;
 };
 
