@@ -38,7 +38,7 @@ public:
     };
 
     explicit SnippetsModel(QObject *parent = nullptr);
-    ~SnippetsModel();
+    ~SnippetsModel() override;
 
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 
@@ -61,7 +61,6 @@ public:
     bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) override;
 
     Qt::DropActions supportedDropActions() const override;
-    QHash<int, QByteArray> roleNames() const override;
 
 protected:
     bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
@@ -72,7 +71,7 @@ Q_SIGNALS:
     void dndDone();
     void addNewDndSnippset(const QString &);
 private:
-    SnippetItem *mRootItem;
+    SnippetItem *mRootItem = nullptr;
 };
 }
 
